@@ -1086,8 +1086,6 @@ class Transaction(object):
             'metadata': self.metadata,
             'asset': self.asset,
             'version': self.version,
-            'app_id': self.app_id,
-            'app_key': self.app_key,
             'id': self._id
         }
 
